@@ -22,7 +22,8 @@
 
 #include <QStandardItemModel>
 
-namespace KWallet {
+namespace KWallet
+{
 class Wallet;
 }
 
@@ -42,5 +43,4 @@ private:
     QMap<QString, QPersistentModelIndex>    _connectedAppsIndexMap;
 };
 
-
 #endif // CONNECTEDAPPMODEL_H
